      subroutine newton(r1,u1,p1,snd1,r2,u2,p2,snd2,labelLgth,label,
     &     uu,pp,IsVacuum)
      implicit none
c
c
      include 'parameters.h'
      include 'input_output.h'
      include 'wave_constants.h'
c
      integer NITER
      parameter (NITER=100)
      real*8 paccur
      parameter (paccur = pre_min)

c     Input:
      real*8 r1,u1,p1,snd1,r2,u2,p2,snd2
      integer labelLgth
      character*80 label
c     Output:
      real*8 uu,pp
      logical IsVacuum
c     Auxiliary:
      real*8 c1,c2,z1,z2,uu1,uu2,dpp
      logical wasVacuum
      integer i
c
c-------------------

      c1 = r1*snd1
      c2 = r2*snd2

      wasVacuum = .false.

      if (PRINT_NEWTON) then
         write(*,*) r1,u1,p1,snd1, r2,u2,p2,snd2
      endif

      if (PRINT_NEWTON_CONV) then
         open(fid_l,file='pu_conv_l_' // label(1:labelLgth) // '.dat')
         open(fid_r,file='pu_conv_r_' // label(1:labelLgth) // '.dat')
      endif

      pp =(c2*p1+c1*p2-c1*c2*(u2-u1))/(c1+c2)

      if (PRINT_NEWTON) then
         write(*,*) label,': Begin Newton Iterations'
      endif

      do i=1,NITER
         if (pp .le. pre_min) then
            pp=pre_min
            if (wasVacuum) then
               IsVacuum = .true.
               if (PRINT_NEWTON_CONV) then
                  close(fid_l)
                  close(fid_r)
               endif
               return
            else
               wasVacuum=.true.
            endif
         else
            wasVacuum=.false.
         endif
c
         call valueAndSlope(pp,r1,u1,p1,snd1,c1,DIR_L,AHEAD,z1,uu1)
         call valueAndSlope(pp,r2,u2,p2,snd2,c2,DIR_R,AHEAD,z2,uu2)

         if (PRINT_NEWTON_CONV) then
            write(fid_l,1000) pp,uu1
            write(fid_r,1000) pp,uu2
         endif

         dpp=-z1*z2*(uu2-uu1)/(z1+z2)

         if (PRINT_NEWTON) then
            write(*,*) i, dpp
         endif
         
         if (dabs(dpp) .lt. paccur) then

            if (pp .le. pre_min) then
               IsVacuum = .true.
            else
               uu=(z1*uu1+z2*uu2)/(z1+z2)
               IsVacuum=.false.
            endif
            if (PRINT_NEWTON_CONV) then
               close(fid_l)
               close(fid_r)
            endif
            return
         endif

         pp = pp + dpp
      enddo
      if (PRINT_NEWTON_CONV) then
         close(fid_l)
         close(fid_r)
      endif

      write(*,*)
      write(*,*) ' Number of iterations exceeded',NITER
      stop

1000  format(2g26.18E2)
      end

