      subroutine printWC(rho_0,vel_0,pre_0,snd_0,dir,centSide, 
     &     preWC_min,preWC_max, labelLgth,label)
      implicit none
c
c     This subroutine saves the (pre,vel)-plane and (pre,rho)-plane   
c     projections 
c     of the wave-curve centered at (rho_0, vel_0, pre_0) state
c     in files with label-based names.
c     There are N1 points in the curve. The wave-curve is computed for 
c     rho \in [preWC_min, preWC_max].
c
c-----------------------------------------------------------------------
c                              INPUT 
c-----------------------------------------------------------------------
c
c     STATE at which the wave-curve is CENTERED
c     -----------------------------------------
c  rho_0    density
c  vel_0    velocity
c  pre_0    pressure
c  snd_0    speed of sound
c
c  dir =1 for right-facing wave, =-1 for left-facing wave
c  centSide =  -1 STATE at which the wave-curve is CENTERED is BEHIND
c              +1 STATE at which the wave-curve is CENTERED is AHEAD
c   
c--------------------------------------------------------------------------
c                             AUXILIARY 
c--------------------------------------------------------------------------
c
c       STATE on the WAVE-CURVE 
c       -----------------------
c    rho  density
c    vel  velocity
c    pre  pressure
c    snd  speed of sound
c
      include 'input_output.h'
      include 'wave_constants.h'

c     Input:
      real*8 rho_0,vel_0,pre_0,snd_0, preWC_min,preWC_max
      integer dir,centSide
      integer labelLgth
      character*80 label
c     Auxiliary:
      integer i,N1
      parameter (N1=1001)
      real*8 dpre, rho, vel, pre, snd, veljump
      real*8 thermSt2snd, veljump2vel, onWaveCurve, st2inv
      external pre2veljumpExpan,pre2veljumpCompr
      real*8 pre2veljumpExpan,pre2veljumpCompr
      external pre2densExpan,pre2densCompr
      real*8 pre2densExpan,pre2densCompr
c-----

      open(fid_pu,file='pu_curv_' // label(1:labelLgth) // '.dat')
      write(fid_pu,1000) pre_0, vel_0
      write(fid_pu,*) '&'

      open(fid_pr,file='pr_curv_' // label(1:labelLgth) // '.dat')
      write(fid_pr,1000) pre_0, rho_0
      write(fid_pr,*) '&'

      open(fid_iLiR,file='iLiR_curv_' // label(1:labelLgth) // '.dat')
      write(fid_iLiR,1000) 
     &     st2inv(vel_0,snd_0,DIR_L), st2inv(vel_0,snd_0,DIR_R) 
      write(fid_iLiR,*) '&'

      dpre  = (preWC_max-preWC_min)/(N1-1)
      do i=1,N1
         pre=preWC_min+(i-1)*dpre
         veljump  = onWaveCurve(pre,pre_0,snd_0,centSide,
     &        pre2veljumpExpan,pre2veljumpCompr)
         rho      = onWaveCurve(pre,pre_0,rho_0,centSide,
     &        pre2densExpan,pre2densCompr)
         vel = veljump2vel(vel_0,veljump,dir)
         snd = thermSt2snd(rho,pre)
         write(fid_pu,1000) pre, vel
         write(fid_pr,1000) pre, rho
         write(fid_iLiR,1000) 
     &        st2inv(vel,snd,DIR_L), st2inv(vel,snd,DIR_R)
      enddo
      write(fid_pu,*) '&'
      close(fid_pu)
      write(fid_pr,*) '&'
      close(fid_pr)
      write(fid_iLiR,*) '&'
      close(fid_iLiR)

 1000 format(f26.8,5x,f26.8)

      end
